@@ -175,6 +175,16 @@ extern int Fitsio_Pthread_Status;
 /*  64-core 8x8-architecture Tile64 platform */
 
 #define BYTESWAPPED TRUE
+
+#elif defined(__sh__)
+
+/* SuperH CPU can be used in both little and big endian modes */
+
+#if defined(__LITTLE_ENDIAN__)
+#define BYTESWAPPED TRUE
+#else
+#define BYTESWAPPED FALSE
+#endif
  
 #else
 
@@ -935,6 +945,7 @@ int imcomp_copy_imheader(fitsfile *infptr, fitsfile *outfptr,
 int imcomp_copy_img2comp(fitsfile *infptr, fitsfile *outfptr, int *status);
 int imcomp_copy_comp2img(fitsfile *infptr, fitsfile *outfptr, 
                           int norec, int *status);
+int imcomp_copy_prime2img(fitsfile *infptr, fitsfile *outfptr, int *status);
 int imcomp_compress_image (fitsfile *infptr, fitsfile *outfptr,
                  int *status);
 int imcomp_compress_tile (fitsfile *outfptr, long row, 
