@@ -12,18 +12,35 @@
 /* #include <sys/stat.h> */
 /* #include <sys/types.h> */
 
-#define	FPACK_VERSION	"1.4.1 (Jan 2010)"
+#define	FPACK_VERSION	"1.6.0 (Feb 2011)"
 /*
 VERSION	History
+1.6.0 (February 2011)
+    - Added full support for compressing and uncompressing FITS binary tables
+      using a newly proposed format convention.  This is intended only for
+      further feasibility studies, and is not recommended for use with publicly
+      distributed FITS files.
+    - Use the minimum of the MAD 2nd, 3rd, and 5th order values as a more
+      conservative extimate of the noise when quantizing floating point images.
+    - Enhanced the tile compression routines so that a tile that contains all
+      NaN pixel values will be compressed.
+    - When uncompressing an image that was originally in a FITS primary array,
+      funpack will also append any new keywords that were written into the 
+      primary array of the compressed FITS file after the file was compressed.
+    - Added support for the GZIP_2 algorithm, which shuffles the bytes in the
+      pixel values prior to compressing them with gzip.      
+1.5.1 (December 2010) Added prototype, mainly hidden, support for compressing 
+      binary tables.  
+1.5.0 (August 2010) Added the -i2f option to lossy compress integer images.
 1.4.0 (Jan 2010) Reduced the default value for the q floating point image 
-      quantization parameter from 16 to 8.  This results in about 15% better
-      compression with no lost of information (especially with the new
-      subtractive dithering enhancement).  Replaced the code for generating
-      temporary filenames to make the code more portable (to Windows). 
-      Replaced calls to the unix 'access' and 'stat' functions with more
-      portable code.   When unpacking a file, write it first to a temporary
-      file, then rename it when finished, so that other tasks cannot try to
-      read the file before it is complete.
+      quantization parameter from 16 to 4.  This results in about 50% better
+      compression (from about 4.6x to 6.4) with no lost of significant information 
+      (with the new subtractive dithering enhancement).  Replaced the code for
+      generating temporary filenames to make the code more portable (to Windows). 
+      Replaced calls to the unix 'access' and 'stat' functions with more portable
+      code.   When unpacking a file, write it first to a temporary file, then
+      rename it when finished, so that other tasks cannot try to read the file
+      before it is complete.
 1.3.0 (Oct 2009) added randomization to the dithering pattern so that
       the same pattern is not used for every image; also added an option
       for losslessly compressing floating point images with GZIP for test 
@@ -62,6 +79,9 @@ typedef struct
 	float	scale;
 	float	rescale_noise;
 	int	smooth;
+	int	int_to_float;
+	float	n3ratio;
+	float	n3min;
 	long	ntile[MAX_COMPRESS_DIM];
 
 	int	to_stdout;
@@ -71,6 +91,8 @@ typedef struct
 	int	do_not_prompt;
 	int	do_checksums;
 	int	do_gzip_file;
+	int     do_tables;  
+	int     do_fast;
 	int	test_all;
 	int	verbose;
 
@@ -92,11 +114,14 @@ typedef struct
 	double	mean;
 	double	sigma;
 	double	noise1;
+	double	noise2;
 	double	noise3;
+	double	noise5;
 } imgstats;
 
 int fp_get_param (int argc, char *argv[], fpstate *fpptr);
 void abort_fpack(int sig);
+void fp_abort_output (fitsfile *infptr, fitsfile *outfptr, int stat); 
 int fp_usage (void);
 int fp_help (void);
 int fp_hint (void); 
@@ -111,7 +136,7 @@ int fp_unpack (char *infits, char *outfits, fpstate fpvar);
 int fp_test (char *infits, char *outfits, char *outfits2, fpstate fpvar);
 int fp_pack_hdu (fitsfile *infptr, fitsfile *outfptr, fpstate fpvar, 
     int *islossless, int *status);
-int fp_unpack_hdu (fitsfile *infptr, fitsfile *outfptr, int *status);
+int fp_unpack_hdu (fitsfile *infptr, fitsfile *outfptr, fpstate fpvar, int *status);
 int fits_read_image_speed (fitsfile *infptr, float *whole_elapse, 
     float *whole_cpu, float *row_elapse, float *row_cpu, int *status);
 int fp_test_hdu (fitsfile *infptr, fitsfile *outfptr, fitsfile *outfptr2, 
@@ -121,9 +146,9 @@ int gettime(float *elapse, float *elapscpu, int *status);
 int fits_read_image_speed (fitsfile *infptr, float *whole_elapse, 
     float *whole_cpu, float *row_elapse, float *row_cpu, int *status);
 
-int fp_i2stat(fitsfile *infptr, int naxis, long *naxes, int *status);
-int fp_i4stat(fitsfile *infptr, int naxis, long *naxes, int *status);
-int fp_r4stat(fitsfile *infptr, int naxis, long *naxes, int *status);
+int fp_i2stat(fitsfile *infptr, int naxis, long *naxes, imgstats *imagestats, int *status);
+int fp_i4stat(fitsfile *infptr, int naxis, long *naxes, imgstats *imagestats, int *status);
+int fp_r4stat(fitsfile *infptr, int naxis, long *naxes, imgstats *imagestats, int *status);
 int fp_i2rescale(fitsfile *infptr, int naxis, long *naxes, double rescale,
     fitsfile *outfptr, int *status);
 int fp_i4rescale(fitsfile *infptr, int naxis, long *naxes, double rescale,
